Metadata
--------

Extraction
^^^^^^^^^^

.. automodule:: s1ard.metadata.extract
    :members:
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        append_wind_norm
        calc_geolocation_accuracy
        calc_pslr_islr
        calc_wm_ref_stats
        copy_src_meta
        find_in_annotation
        get_osv_info
        get_prod_meta
        get_src_meta
        meta_dict

STAC
^^^^

.. automodule:: s1ard.metadata.stac
    :members:
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        make_catalog